# Changelog

All notable changes to this project will be documented in this file.

## [0.0.6] - 2024-08-04
### Added
- Added `--csv-table` functionality to parse items from PDF or JSON files and save them into a single CSV table.
- Added basic documentation in docstrings
- Fix issues with parsing addresses from certain receipts.

## [0.0.5] - 2024-08-04
### Added
- Initial release of the `rewe-ebon-parser` package.
